@@ -36,6 +36,8 @@ __all__ = [
     "BOT_API_VERSION_INFO",
     "BotCommandLimit",
     "BotCommandScopeType",
+    "BotDescriptionLimit",
+    "BotNameLimit",
     "CallbackQueryLimit",
     "ChatAction",
     "ChatID",
@@ -56,6 +58,7 @@ __all__ = [
     "InlineKeyboardMarkupLimit",
     "InlineQueryLimit",
     "InlineQueryResultLimit",
+    "InlineQueryResultsButtonLimit",
     "InlineQueryResultType",
     "InputMediaType",
     "InvoiceLimit",
@@ -73,7 +76,9 @@ __all__ = [
     "PollType",
     "ReplyLimit",
     "SUPPORTED_WEBHOOK_PORTS",
+    "StickerFormat",
     "StickerLimit",
+    "StickerSetLimit",
     "StickerType",
     "WebhookLimit",
     "UpdateType",
@@ -81,7 +86,7 @@ __all__ = [
 ]
 
 import sys
-from typing import List, NamedTuple
+from typing import Final, List, NamedTuple
 
 from telegram._utils.enum import IntEnum, StringEnum
 
@@ -111,19 +116,19 @@ class _BotAPIVersion(NamedTuple):
 #: :data:`telegram.__bot_api_version_info__`.
 #:
 #: .. versionadded:: 20.0
-BOT_API_VERSION_INFO = _BotAPIVersion(major=6, minor=5)
+BOT_API_VERSION_INFO: Final[_BotAPIVersion] = _BotAPIVersion(major=6, minor=8)
 #: :obj:`str`: Telegram Bot API
 #: version supported by this version of `python-telegram-bot`. Also available as
 #: :data:`telegram.__bot_api_version__`.
 #:
 #: .. versionadded:: 13.4
-BOT_API_VERSION = str(BOT_API_VERSION_INFO)
+BOT_API_VERSION: Final[str] = str(BOT_API_VERSION_INFO)
 
 # constants above this line are tested
 
 #: List[:obj:`int`]: Ports supported by
 #:  :paramref:`telegram.Bot.set_webhook.url`.
-SUPPORTED_WEBHOOK_PORTS: List[int] = [443, 80, 88, 8443]
+SUPPORTED_WEBHOOK_PORTS: Final[List[int]] = [443, 80, 88, 8443]
 
 
 class BotCommandLimit(IntEnum):
@@ -184,6 +189,43 @@ class BotCommandScopeType(StringEnum):
     """:obj:`str`: The type of :class:`telegram.BotCommandScopeChatMember`."""
 
 
+class BotDescriptionLimit(IntEnum):
+    """This enum contains limitations for the methods :meth:`telegram.Bot.set_my_description` and
+    :meth:`telegram.Bot.set_my_short_description`. The enum members of this enumeration are
+    instances of :class:`int` and can be treated as such.
+
+    .. versionadded:: 20.2
+    """
+
+    __slots__ = ()
+
+    MAX_DESCRIPTION_LENGTH = 512
+    """:obj:`int`: Maximum length for the parameter
+    :paramref:`~telegram.Bot.set_my_description.description` of
+    :meth:`telegram.Bot.set_my_description`
+    """
+    MAX_SHORT_DESCRIPTION_LENGTH = 120
+    """:obj:`int`: Maximum length for the parameter
+    :paramref:`~telegram.Bot.set_my_short_description.short_description` of
+    :meth:`telegram.Bot.set_my_short_description`
+    """
+
+
+class BotNameLimit(IntEnum):
+    """This enum contains limitations for the methods :meth:`telegram.Bot.set_my_name`.
+    The enum members of this enumeration are instances of :class:`int` and can be treated as such.
+
+    .. versionadded:: 20.3
+    """
+
+    __slots__ = ()
+
+    MAX_NAME_LENGTH = 64
+    """:obj:`int`: Maximum length for the parameter :paramref:`~telegram.Bot.set_my_name.name` of
+    :meth:`telegram.Bot.set_my_name`
+    """
+
+
 class CallbackQueryLimit(IntEnum):
     """This enum contains limitations for :class:`telegram.CallbackQuery`/
     :meth:`telegram.Bot.answer_callback_query`. The enum members of this enumeration are instances
@@ -243,7 +285,8 @@ class ChatID(IntEnum):
     __slots__ = ()
 
     ANONYMOUS_ADMIN = 1087968824
-    """:obj:`int`: User ID in groups for messages sent by anonymous admins.
+    """:obj:`int`: User ID in groups for messages sent by anonymous admins. Telegram chat:
+    `@GroupAnonymousBot <https://t.me/GroupAnonymousBot>`_.
 
     Note:
         :attr:`telegram.Message.from_user` will contain this ID for backwards compatibility only.
@@ -251,19 +294,21 @@ class ChatID(IntEnum):
     """
     SERVICE_CHAT = 777000
     """:obj:`int`: Telegram service chat, that also acts as sender of channel posts forwarded to
-    discussion groups.
+    discussion groups. Telegram chat: `Telegram <https://t.me/+42777>`_.
 
     Note:
         :attr:`telegram.Message.from_user` will contain this ID for backwards compatibility only.
         It's recommended to use :attr:`telegram.Message.sender_chat` instead.
     """
     FAKE_CHANNEL = 136817688
-    """:obj:`int`: User ID in groups when message is sent on behalf of a channel.
+    """:obj:`int`: User ID in groups when message is sent on behalf of a channel, or when a channel
+    votes on a poll. Telegram chat: `@Channel_Bot <https://t.me/Channel_Bot>`_.
 
     Note:
         * :attr:`telegram.Message.from_user` will contain this ID for backwards compatibility only.
           It's recommended to use :attr:`telegram.Message.sender_chat` instead.
-        * This value is undocumented and might be changed by Telegram.
+        * :attr:`telegram.PollAnswer.user` will contain this ID for backwards compatibility only.
+          It's recommended to use :attr:`telegram.PollAnswer.voter_chat` instead.
     """
 
 
@@ -710,11 +755,19 @@ class InlineQueryLimit(IntEnum):
     MIN_SWITCH_PM_TEXT_LENGTH = 1
     """:obj:`int`: Minimum number of characters in a :obj:`str` passed as the
     :paramref:`~telegram.Bot.answer_inline_query.switch_pm_parameter` parameter of
-    :meth:`telegram.Bot.answer_inline_query`."""
+    :meth:`telegram.Bot.answer_inline_query`.
+
+    .. deprecated:: 20.3
+        Deprecated in favor of :attr:`InlineQueryResultsButtonLimit.MIN_START_PARAMETER_LENGTH`.
+    """
     MAX_SWITCH_PM_TEXT_LENGTH = 64
     """:obj:`int`: Maximum number of characters in a :obj:`str` passed as the
     :paramref:`~telegram.Bot.answer_inline_query.switch_pm_parameter` parameter of
-    :meth:`telegram.Bot.answer_inline_query`."""
+    :meth:`telegram.Bot.answer_inline_query`.
+
+    .. deprecated:: 20.3
+        Deprecated in favor of :attr:`InlineQueryResultsButtonLimit.MAX_START_PARAMETER_LENGTH`.
+    """
 
 
 class InlineQueryResultLimit(IntEnum):
@@ -738,6 +791,26 @@ class InlineQueryResultLimit(IntEnum):
     """
 
 
+class InlineQueryResultsButtonLimit(IntEnum):
+    """This enum contains limitations for :class:`telegram.InlineQueryResultsButton`.
+    The enum members of this enumeration are instances of :class:`int` and can be treated as such.
+
+    .. versionadded:: 20.3
+    """
+
+    __slots__ = ()
+
+    MIN_START_PARAMETER_LENGTH = InlineQueryLimit.MIN_SWITCH_PM_TEXT_LENGTH
+    """:obj:`int`: Minimum number of characters in a :obj:`str` passed as the
+    :paramref:`~telegram.InlineQueryResultsButton.start_parameter` parameter of
+    :meth:`telegram.InlineQueryResultsButton`."""
+
+    MAX_START_PARAMETER_LENGTH = InlineQueryLimit.MAX_SWITCH_PM_TEXT_LENGTH
+    """:obj:`int`: Maximum number of characters in a :obj:`str` passed as the
+    :paramref:`~telegram.InlineQueryResultsButton.start_parameter` parameter of
+    :meth:`telegram.InlineQueryResultsButton`."""
+
+
 class InlineQueryResultType(StringEnum):
     """This enum contains the available types of :class:`telegram.InlineQueryResult`. The enum
     members of this enumeration are instances of :class:`str` and can be treated as such.
@@ -995,6 +1068,8 @@ class MessageAttachmentType(StringEnum):
     """:obj:`str`: Messages with :attr:`telegram.Message.poll`."""
     STICKER = "sticker"
     """:obj:`str`: Messages with :attr:`telegram.Message.sticker`."""
+    STORY = "story"
+    """:obj:`str`: Messages with :attr:`telegram.Message.story`."""
     SUCCESSFUL_PAYMENT = "successful_payment"
     """:obj:`str`: Messages with :attr:`telegram.Message.successful_payment`."""
     VIDEO = "video"
@@ -1149,6 +1224,8 @@ class MessageType(StringEnum):
     """:obj:`str`: Messages with :attr:`telegram.Message.poll`."""
     STICKER = "sticker"
     """:obj:`str`: Messages with :attr:`telegram.Message.sticker`."""
+    STORY = "story"
+    """:obj:`str`: Messages with :attr:`telegram.Message.story`."""
     SUCCESSFUL_PAYMENT = "successful_payment"
     """:obj:`str`: Messages with :attr:`telegram.Message.successful_payment`."""
     VIDEO = "video"
@@ -1243,8 +1320,26 @@ class ReplyLimit(IntEnum):
     """
 
 
+class StickerFormat(StringEnum):
+    """This enum contains the available formats of :class:`telegram.Sticker` in the set. The enum
+    members of this enumeration are instances of :class:`str` and can be treated as such.
+
+    .. versionadded:: 20.2
+    """
+
+    __slots__ = ()
+
+    STATIC = "static"
+    """:obj:`str`: Static sticker."""
+    ANIMATED = "animated"
+    """:obj:`str`: Animated sticker."""
+    VIDEO = "video"
+    """:obj:`str`: Video sticker."""
+
+
 class StickerLimit(IntEnum):
-    """This enum contains limitations for :meth:`telegram.Bot.create_new_sticker_set`.
+    """This enum contains limitations for various sticker methods, such as
+    :meth:`telegram.Bot.create_new_sticker_set`.
     The enum members of this enumeration are instances of :class:`int` and can be treated as such.
 
     .. versionadded:: 20.0
@@ -1264,6 +1359,78 @@ class StickerLimit(IntEnum):
     :paramref:`~telegram.Bot.create_new_sticker_set.title` parameter of
     :meth:`telegram.Bot.create_new_sticker_set`.
     """
+    MIN_STICKER_EMOJI = 1
+    """:obj:`int`: Minimum number of emojis associated with a sticker, passed as the
+    :paramref:`~telegram.Bot.setStickerEmojiList.emoji_list` parameter of
+    :meth:`telegram.Bot.set_sticker_emoji_list`.
+
+    .. versionadded:: 20.2
+    """
+    MAX_STICKER_EMOJI = 20
+    """:obj:`int`: Maximum number of emojis associated with a sticker, passed as the
+    :paramref:`~telegram.Bot.setStickerEmojiList.emoji_list` parameter of
+    :meth:`telegram.Bot.set_sticker_emoji_list`.
+
+    .. versionadded:: 20.2
+    """
+    MAX_SEARCH_KEYWORDS = 20
+    """:obj:`int`: Maximum number of search keywords for a sticker, passed as the
+    :paramref:`~telegram.Bot.set_sticker_keywords.keywords` parameter of
+    :meth:`telegram.Bot.set_sticker_keywords`.
+
+    .. versionadded:: 20.2
+    """
+    MAX_KEYWORD_LENGTH = 64
+    """:obj:`int`: Maximum number of characters in a search keyword for a sticker, for each item in
+    :paramref:`~telegram.Bot.set_sticker_keywords.keywords` sequence of
+    :meth:`telegram.Bot.set_sticker_keywords`.
+
+    .. versionadded:: 20.2
+    """
+
+
+class StickerSetLimit(IntEnum):
+    """This enum contains limitations for various sticker set methods, such as
+    :meth:`telegram.Bot.create_new_sticker_set` and :meth:`telegram.Bot.add_sticker_to_set`.
+
+    The enum members of this enumeration are instances of :class:`int` and can be treated as such.
+
+    .. versionadded:: 20.2
+    """
+
+    __slots__ = ()
+
+    MIN_INITIAL_STICKERS = 1
+    """:obj:`int`: Minimum number of stickers needed to create a sticker set, passed as the
+    :paramref:`~telegram.Bot.create_new_sticker_set.stickers` parameter of
+    :meth:`telegram.Bot.create_new_sticker_set`.
+    """
+    MAX_INITIAL_STICKERS = 50
+    """:obj:`int`: Maximum number of stickers allowed while creating a sticker set, passed as the
+    :paramref:`~telegram.Bot.create_new_sticker_set.stickers` parameter of
+    :meth:`telegram.Bot.create_new_sticker_set`.
+    """
+    MAX_EMOJI_STICKERS = 200
+    """:obj:`int`: Maximum number of stickers allowed in an emoji sticker set, as given in
+    :meth:`telegram.Bot.add_sticker_to_set`.
+    """
+    MAX_ANIMATED_STICKERS = 50
+    """:obj:`int`: Maximum number of stickers allowed in an animated or video sticker set, as given
+    in :meth:`telegram.Bot.add_sticker_to_set`.
+    """
+    MAX_STATIC_STICKERS = 120
+    """:obj:`int`: Maximum number of stickers allowed in a static sticker set, as given in
+    :meth:`telegram.Bot.add_sticker_to_set`.
+    """
+    MAX_STATIC_THUMBNAIL_SIZE = 128
+    """:obj:`int`: Maximum size of the thumbnail if it is a **.WEBP** or **.PNG** in kilobytes,
+    as given in :meth:`telegram.Bot.set_sticker_set_thumbnail`."""
+    MAX_ANIMATED_THUMBNAIL_SIZE = 32
+    """:obj:`int`: Maximum size of the thumbnail if it is a **.TGS** or **.WEBM** in kilobytes,
+    as given in :meth:`telegram.Bot.set_sticker_set_thumbnail`."""
+    STATIC_THUMB_DIMENSIONS = 100
+    """:obj:`int`: Exact height and width of the thumbnail if it is a **.WEBP** or **.PNG** in
+    pixels, as given in :meth:`telegram.Bot.set_sticker_set_thumbnail`."""
 
 
 class StickerType(StringEnum):
