@@ -18,14 +18,14 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an abstract class to make POST and GET requests."""
 import abc
-import asyncio
 import json
 from http import HTTPStatus
 from types import TracebackType
-from typing import AsyncContextManager, ClassVar, List, Optional, Tuple, Type, TypeVar, Union
+from typing import AsyncContextManager, Final, List, Optional, Tuple, Type, TypeVar, Union, final
 
 from telegram._utils.defaultvalue import DEFAULT_NONE as _DEFAULT_NONE
 from telegram._utils.defaultvalue import DefaultValue
+from telegram._utils.logging import get_logger
 from telegram._utils.types import JSONDict, ODVInput
 from telegram._version import __version__ as ptb_ver
 from telegram.error import (
@@ -42,6 +42,8 @@ from telegram.request._requestdata import RequestData
 
 RT = TypeVar("RT", bound="BaseRequest")
 
+_LOGGER = get_logger(__name__, class_name="BaseRequest")
+
 
 class BaseRequest(
     AsyncContextManager["BaseRequest"],
@@ -81,10 +83,10 @@ class BaseRequest(
 
     __slots__ = ()
 
-    USER_AGENT: ClassVar[str] = f"python-telegram-bot v{ptb_ver} (https://python-telegram-bot.org)"
+    USER_AGENT: Final[str] = f"python-telegram-bot v{ptb_ver} (https://python-telegram-bot.org)"
     """:obj:`str`: A description that can be used as user agent for requests made to the Bot API.
     """
-    DEFAULT_NONE: ClassVar[DefaultValue[None]] = _DEFAULT_NONE
+    DEFAULT_NONE: Final[DefaultValue[None]] = _DEFAULT_NONE
     """:class:`object`: A special object that indicates that an argument of a function was not
     explicitly passed. Used for the timeout parameters of :meth:`post` and :meth:`do_request`.
 
@@ -122,10 +124,11 @@ class BaseRequest(
     async def shutdown(self) -> None:
         """Stop & clear resources used by this class. Must be implemented by a subclass."""
 
+    @final
     async def post(
         self,
         url: str,
-        request_data: RequestData = None,
+        request_data: Optional[RequestData] = None,
         read_timeout: ODVInput[float] = DEFAULT_NONE,
         write_timeout: ODVInput[float] = DEFAULT_NONE,
         connect_timeout: ODVInput[float] = DEFAULT_NONE,
@@ -176,6 +179,7 @@ class BaseRequest(
         # see https://core.telegram.org/bots/api#making-requests
         return json_data["result"]
 
+    @final
     async def retrieve(
         self,
         url: str,
@@ -226,7 +230,7 @@ class BaseRequest(
         self,
         url: str,
         method: str,
-        request_data: RequestData = None,
+        request_data: Optional[RequestData] = None,
         read_timeout: ODVInput[float] = DEFAULT_NONE,
         write_timeout: ODVInput[float] = DEFAULT_NONE,
         connect_timeout: ODVInput[float] = DEFAULT_NONE,
@@ -280,14 +284,10 @@ class BaseRequest(
                 connect_timeout=connect_timeout,
                 pool_timeout=pool_timeout,
             )
-        except asyncio.CancelledError as exc:
-            # TODO: in py3.8+, CancelledError is a subclass of BaseException, so we can drop this
-            #  clause when we drop py3.7
-            raise exc
         except TelegramError as exc:
             raise exc
         except Exception as exc:
-            raise NetworkError(f"Unknown error in HTTP implementation: {repr(exc)}") from exc
+            raise NetworkError(f"Unknown error in HTTP implementation: {exc!r}") from exc
 
         if HTTPStatus.OK <= code <= 299:
             # 200-299 range are HTTP success statuses
@@ -296,10 +296,7 @@ class BaseRequest(
         response_data = self.parse_json_payload(payload)
 
         description = response_data.get("description")
-        if description:
-            message = description
-        else:
-            message = "Unknown HTTPError"
+        message = description if description else "Unknown HTTPError"
 
         # In some special cases, we can raise more informative exceptions:
         # see https://core.telegram.org/bots/api#responseparameters and
@@ -354,6 +351,7 @@ class BaseRequest(
         try:
             return json.loads(decoded_s)
         except ValueError as exc:
+            _LOGGER.error('Can not load invalid JSON data: "%s"', decoded_s)
             raise TelegramError("Invalid server response") from exc
 
     @abc.abstractmethod
@@ -361,7 +359,7 @@ class BaseRequest(
         self,
         url: str,
         method: str,
-        request_data: RequestData = None,
+        request_data: Optional[RequestData] = None,
         read_timeout: ODVInput[float] = DEFAULT_NONE,
         write_timeout: ODVInput[float] = DEFAULT_NONE,
         connect_timeout: ODVInput[float] = DEFAULT_NONE,
